@@ -1,10 +1,10 @@
 /**************************************************************************
    zfuncs.h      include file for zfuncs functions
 
-   Copyright 2006-2014 Michael Cornelison
+   Copyright 2006-2015 Michael Cornelison
    source URL:  kornelix.com
    contact: kornelix@posteo.de
-   
+
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
@@ -20,9 +20,9 @@
 
 ***************************************************************************/
 
-//     zfuncs.h   version  v.6.0
+//     zfuncs.h   version  v.6.2
 
-#include <sys/sysinfo.h> 
+#include <sys/sysinfo.h>
 #include <sys/time.h>
 #include <sys/stat.h>
 #include <sys/resource.h>
@@ -46,6 +46,8 @@
 
 #define VERTICAL GTK_ORIENTATION_VERTICAL                                  //  GTK shortcuts
 #define HORIZONTAL GTK_ORIENTATION_HORIZONTAL
+#define PIXBUF GdkPixbuf
+#define GDKCOLOR GdkColorspace
 
 #define  int8   char                                                       //  number types
 #define  int16  short
@@ -59,24 +61,24 @@
 #define  cchar  const char
 
 #define  wstrerror(err) strerror(WEXITSTATUS(err))                         //  get text status for child process
-#define  STATB  struct stat
 
-#define  mutex_tp       pthread_mutex_t                                    //  abbreviations
+#define  STATB  struct stat                                                //  stat() file status buffer
+
+#define  mutex_t        pthread_mutex_t                                    //  abbreviations
 #define  mutex_init     pthread_mutex_init
 #define  mutex_lock     pthread_mutex_lock
 #define  mutex_trylock  pthread_mutex_trylock
 #define  mutex_unlock   pthread_mutex_unlock
 #define  mutex_destroy  pthread_mutex_destroy
 
-#define  maxfcc 1000                                                       //  max. file pathname cc tolerated
+#define  XFCC 1000                                                         //  max. file pathname cc tolerated
 #define  null   NULL
 #define  true   1
 #define  false  0
 
-//  trace execution: output file, function, line no, caller address
+//  trace execution: source file, function, line no, caller address
 
-#define TRACE     \
-   trace(__FILE__,__FUNCTION__,__LINE__,__builtin_return_address(0));
+#define TRACE trace(__FILE__,__FUNCTION__,__LINE__,__builtin_return_address(0));
 
 //  system functions ======================================================
 
@@ -86,7 +88,7 @@ char *zstrdup(cchar *string, int addcc = 0);                               //  s
 void zmalloc_report();                                                     //  print statistics report            v.5.9
 
 void printz(cchar *format, ...);                                           //  printf() with immediate fflush()   v.5.8
-void zpopup_message(cchar *format, ...);                                   //  popup message, thread safe
+void zpopup_message(int secs, cchar *format, ...);                         //  popup message, thread safe
 
 void zbacktrace();                                                         //  produce a backtrace to stdout      v.5.9
 void zappcrash(cchar *format, ...);                                        //  crash with popup message in text window
@@ -102,24 +104,25 @@ double get_timer(double &time0);                                           //  g
 void start_CPUtimer(double &time0);                                        //  start a process CPU timer
 double get_CPUtimer(double &time0);                                        //  get elapsed CPU time, seconds
 double CPUtime();                                                          //  get elapsed process CPU time for main()
-double CPUtime2();                                                         //   " include all threads 
+double CPUtime2();                                                         //   " include all threads
 double jobtime();                                                          //   " include all threads + subprocesses
 void compact_time(const time_t fileDT, char *compactDT);                   //  time_t date/time to yyyymmddhhmmss
 int  parseprocfile(cchar *pfile, cchar *pname, double *value, ...);        //  get data from /proc file
 int  parseprocrec(char *prec, int field, double *value, ...);              //  get data from /proc file record
-void coretemps(int &lotemp, int &hitemp);                                  //  get low and high cpu core temps    v.5.9
+int  coretemp();                                                           //  get CPU core temperature, deg. C   v.6.1
 int  disktemp(char *disk);                                                 //  get disk temp, e.g. "/dev/sda"     v.5.9
 void zsleep(double dsecs);                                                 //  sleep specified seconds
-int global_lock(cchar *lockfile);                                          //  obtain exclusive lock, multi-process
-int global_unlock(int fd, cchar *lockfile);                                //  release the lock
-
-void start_detached_thread(void * tfunc(void *), void * arg);              //  start detached thread function
-void synch_threads(int NT = 0);                                            //  synchronize NT threads
-
+int  global_lock(cchar *lockfile);                                         //  obtain exclusive lock, multi-process
+int  global_unlock(int fd, cchar *lockfile);                               //  release the lock
+int  resource_lock(int &resource);                                         //  simple lock/unlock usable with GTK
+void resource_unlock(int &resource);                                       //  (never waits, returns lock status)
 int  zget_locked(int &param);                                              //  lock and get multi-thread parameter
 void zput_locked(int &param, int value);                                   //  put and unlock multi-thread parameter
 int  zadd_locked(int &param, int incr);                                    //  increment multi-thread parameter
 
+void start_detached_thread(void * tfunc(void *), void * arg);              //  start detached thread function
+void synch_threads(int NT = 0);                                            //  synchronize NT threads
+
 int shell_quiet(cchar *command, ...);                                      //  format/run shell command, return status
 int shell_ack(cchar *command, ...);                                        //   ""  + popup an error message if error
 int shell_asynch(cchar *command, ...);                                     //  start shell command, return immediately
@@ -150,12 +153,10 @@ int pagefaultrate();                                                       //  m
 
 //  string macros and functions ===========================================
 
-#define strEqu(str1,str2) (! strcmp((str1),(str2)))                        //  TRUE if strings compare equal
-#define strcaseEqu(str1,str2) (! strcasecmp((str1),(str2)))                //  TRUE if strings equal, ignoring case
-#define strNeq(str1,str2) (strcmp((str1),(str2)))                          //  TRUE if strings compare not-equal
-#define strnEqu(str1,str2,cc) (! strncmp((str1),(str2),(cc)))              //  TRUE if strings[cc] compare equal
-#define strncaseEqu(str1,str2,cc) (! strncasecmp((str1),(str2),(cc)))      //  TRUE if strings[cc] equal, ignoring case
-#define strnNeq(str1,str2,cc) (strncmp((str1),(str2),(cc)))                //  TRUE if strings[cc] compare not-equal
+#define strmatch(str1,str2) (! strcmp((str1),(str2)))                      //  TRUE if strings equal
+#define strmatchN(str1,str2,cc) (! strncmp((str1),(str2),(cc)))            //  TRUE if strings[cc] equal
+#define strmatchcase(str1,str2) (! strcasecmp((str1),(str2)))              //  TRUE if strings equal, ignoring case
+#define strmatchcaseN(str1,str2,cc) (! strncasecmp((str1),(str2),(cc)))    //  TRUE if strings[cc] equal, ignoring case
 
 cchar * strField(cchar *string, cchar *delims, int Nth);                   //  get Nth delimited field in string
 cchar * strField(cchar *string, cchar delim, int Nth);                     //  get Nth delimited field in string
@@ -169,14 +170,15 @@ int  strTrim2(char *dest, cchar *source);                                  //  r
 int  strTrim2(char *string);                                               //  remove leading and trailing blanks
 int  strCompress(char *dest, cchar *source);                               //  remove all blanks incl. imbedded
 int  strCompress(char *string);                                            //  remove all blanks
-int  strncatv(char *dest, int maxcc, cchar *source, ...);                  //  catenate strings (last = null) 
-int  strcmpv(cchar *string, ...);                                          //  compare to N strings, return 1-N or 0
+int  strncatv(char *dest, int maxcc, cchar *source, ...);                  //  catenate strings (last = null)
+int  strmatchV(cchar *string, ...);                                        //  compare to N strings, return 1-N or 0
 void strToUpper(char *dest, cchar *source);                                //  move and conv. string to upper case
 void strToUpper(char *string);                                             //  conv. string to upper case
 void strToLower(char *dest, cchar *source);                                //  move and conv. string to lower case
 void strToLower(char *string);                                             //  conv. string to lower case
 int  repl_1str(cchar *strin, char *strout, cchar *ssin, cchar *ssout);     //  copy string and replace 1 substring
 int  repl_Nstrs(cchar *strin, char *strout, ...);                          //  copy string and replace N substrings
+int  breakup_text(cchar *in, char **&out, cchar *dlm, int cc1, int cc2);   //  break long string into substrings for output
 void strncpyx(char *out, cchar *in, int ccin);                             //  conv. string to hex format
 void StripZeros(char *pNum);                                               //  1.230000E+12 --> 1.23E+12
 int  blank_null(cchar *string);                                            //  test for blank/null string
@@ -217,7 +219,7 @@ void HeapSort(float vv[], int nn);                                         //  H
 void HeapSort(double vv[], int nn);                                        //  Heap Sort - double
 void HeapSort(char *vv[], int nn);                                         //  Heap Sort - char *, ascending order
 void HeapSort(char *vv1[], char *vv2[], int nn);                           //  Heap Sort - parallel char *, ascending order
-void HeapSort(char *vv[], int nn, HeapSortUcomp);                          //  Heap Sort - char *, user-defined order 
+void HeapSort(char *vv[], int nn, HeapSortUcomp);                          //  Heap Sort - char *, user-defined order
 void HeapSort(char *recs, int RL, int NR, HeapSortUcomp);                  //  Heap Sort - records, user-defined order
 
 int MemSort(char * RECS, int RL, int NR, int KEYS[][3], int NK);           //  memory sort, records with multiple keys
@@ -267,15 +269,15 @@ typedef struct  {
 void Qtext_open(Qtext *qtext, int cap);                                    //  initialize Qtext queue, empty
 void Qtext_put(Qtext *qtext, cchar *format, ...);                          //  add text string to Qtext queue
 char * Qtext_get(Qtext *qtext);                                            //  remove text string from Qtext queue
-void Qtext_close(Qtext *qtext);                                            //  free() leftover strings if any
+void Qtext_close(Qtext *qtext);                                            //  close Qtext, zfree() leftover strings
 
 //  application initialization and administration =========================
 
-int zinitapp(cchar *appname, ...);                                         //  initz. app directories and files   v.4.1
+int zinitapp(cchar *appname);                                              //  initz. app directories and files   v.4.1
 cchar * get_zprefix();                                                     //  get /usr or /usr/local  ...        v.4.1
 cchar * get_zuserdir();                                                    //  get /home/user/.appname/
 cchar * get_zdatadir();                                                    //  get data directory
-cchar * get_zdocdir();                                                     //  get document directory 
+cchar * get_zdocdir();                                                     //  get document directory
 cchar * get_zicondir();                                                    //  get icon directory                 v.5.7
 int  locale_filespec(cchar *ftype, cchar *fname, char *filespec);          //  get a locale dependent file        v.5.5
 
@@ -302,12 +304,13 @@ cchar * ZTX_missing(int &ftf);                                             //  g
 
 void zmainloop(int skip = 0);                                              //  do main loop, process menu events
 void zthreadcrash();                                                       //  crash if thread is not main() thread
+
 void get_hardware_info(GtkWidget *);                                       //  get hardware info (display, screen, mouse)
 int  move_pointer(GtkWidget *, int px, int py);                            //  move the mouse pointer to px, py
 
 //  text window print and read utilities
 
-void wprintx(GtkWidget *Win, int line, cchar *mess, cchar *font = 0);      //  write text to line, optional font
+void wprintx(GtkWidget *Win, int line, cchar *mess, int bold = 0);         //  write text to line, optional bold  6.2
 void wprintf(GtkWidget *Win, int line, cchar *format, ...);                //  "printf" version
 void wprintf(GtkWidget *Win, cchar *format, ... );                         //  "printf" to next line, scroll up
 void wscroll(GtkWidget *mLog, int line);                                   //  scroll window to put line on screen
@@ -315,7 +318,7 @@ void wclear(GtkWidget *Win);                                               //  c
 void wclear(GtkWidget *Win, int line);                                     //  clear from line to end
 char * wscanf(GtkWidget *Win, int &ftf);                                   //  get text lines from edit widget
 int  wfiledump(GtkWidget *Win, char *filespec);                            //  dump text window to file
-void wfilesave(GtkWidget *Win);                                            //  wfiledump() via file-chooser dialog
+void wfilesave(GtkWidget *Win, GtkWindow *parent);                         //  wfiledump() via file-chooser dialog
 void wprintp(GtkWidget *Win);                                              //  print text window to default printer
 
 //  intercept text window mouse click functions
@@ -335,8 +338,8 @@ char * textwidget_get_word(char *line, int pos, cchar *dlims, char &end);  //  g
 typedef void cbFunc(GtkWidget *, cchar *mname);                                  //  menu or button response function
 
 GtkWidget * create_menubar(GtkWidget *vbox);                                     //  create menubar in packing box
-GtkWidget * add_menubar_item(GtkWidget *mbar, cchar *mname, cbFunc func = 0);    //  add menu item to menubar 
-GtkWidget * add_submenu_item(GtkWidget *mitem, cchar *subname,                   //  add submenu item to menu item 
+GtkWidget * add_menubar_item(GtkWidget *mbar, cchar *mname, cbFunc func = 0);    //  add menu item to menubar
+GtkWidget * add_submenu_item(GtkWidget *mitem, cchar *subname,                   //  add submenu item to menu item
                              cbFunc func = 0, cchar *mtip = 0);                  //    with opt. function and popup tip
 
 GtkWidget * create_toolbar(GtkWidget *vbox, int iconsize = 24);            //  toolbar in packing box (no vert gtk3)
@@ -371,7 +374,7 @@ struct vmenuent {                                                          //  m
    cchar       *desc;                                                      //  description (mouse hover popup)
    cbFunc      *func;                                                      //  callback func (GtkWidget *, cchar *arg)
    cchar       *arg;                                                       //  callback arg
-   GdkPixbuf   *pixbuf;                                                    //  icon pixbuf or null
+   PIXBUF      *pixbuf;                                                    //  icon pixbuf or null
    PangoLayout *playout1, *playout2;                                       //  normal and bold menu text
    int         namex, namey;                                               //  menu name position in layout
    int         iconx, icony;                                               //  menu icon position
@@ -388,14 +391,14 @@ struct Vmenu {
 };
 
 Vmenu *Vmenu_new(GtkWidget *vbox);                                         //  create new menu in parent vbox
-void Vmenu_add(Vmenu *vbm, cchar *name, cchar *icon,                       //  add menu item with response function 
-               int iconww, int iconhh, cchar *desc, 
-               cbFunc func, cchar *arg);                                   //  function may be popup_menu() 
+void Vmenu_add(Vmenu *vbm, cchar *name, cchar *icon,                       //  add menu item with response function
+               int iconww, int iconhh, cchar *desc,
+               cbFunc func, cchar *arg);                                   //  function may be popup_menu()
 
 /**************************************************************************/
 
 //   functions to implement GTK dialogs with less complexity
-//   widget types: dialog, hbox, vbox, hsep, vsep, frame, scrwin, label, entry, edit, radio, 
+//   widget types: dialog, hbox, vbox, hsep, vsep, frame, scrwin, label, entry, edit, radio,
 //                 check, button, togbutt, spin, combo, comboE, hscale, vscale, colorbutt
 
 #define zdmaxwidgets 300                           //  v.5.8
@@ -408,12 +411,14 @@ struct zwidget  {
       cchar       *pname;                          //  parent (container) name
       char        *data;                           //  widget data, initial / returned
       pvlist      *cblist;                         //  combo box drop-down list
-      int         scc;                             //  entry widget: text cc width
+      int         size;                            //  text entry cc or image pixel size
       int         homog;                           //  hbox/vbox: equal spacing flag
-      int         expand;                          //  expandable flag
+      int         expand;                          //  widget is expandable flag
       int         space;                           //  extra padding space (pixels)
       int         wrap;                            //  wrap mode for edit widget
       int         stopKB;                          //  stop propagation of KB events to parent
+      int         rescale;                         //  widget is rescaled for more resolution                     v.6.0
+      float       lval, nval, hval;                //  scale range and neutral value
       GtkWidget   *widget;                         //  GTK widget pointer
 };
 
@@ -426,29 +431,34 @@ struct zdialog  {
       int         saveinputs;                      //  save and recall user inputs each use
       int         stopKB;                          //  flag, next KB event will be ignored
       GtkWidget   *parent;                         //  parent window or null
-      cchar       *compbutton[zdmaxbutts];         //  dialog completion button labels                      v.5.9
+      cchar       *compbutton[zdmaxbutts];         //  dialog completion button labels                            v.5.9
       GtkWidget   *compwidget[zdmaxbutts];         //  dialog completion button widgets
       zwidget     widget[zdmaxwidgets];            //  dialog widgets (EOF = type = 0)
 };
 
 zdialog *zdialog_new(cchar *title, GtkWidget *parent, ...);                //  create a zdialog with opt. buttons
+void zdialog_set_title(zdialog *zd, cchar *title);                         //  change zdialog title               v.6.0
+void zdialog_set_modal(zdialog *zd);                                       //  set zdialog modal                  v.6.1
+void zdialog_set_decorated(zdialog *zd, int decorated);                    //  set zdialog decorated or not       v.6.1
+void zdialog_present(zdialog *zd);                                         //  zdialog visible and on top         v.6.1
 
 int zdialog_add_widget(zdialog *zd,                                        //  add widget to zdialog
       cchar *type, cchar *name, cchar *pname,                              //  required args
-      cchar *data = 0, int scc = 0, int homog = 0,                         //  optional args
+      cchar *data = 0, int size = 0, int homog = 0,                        //  optional args
       int expand = 0, int space = 0, int wrap = 0);
 
 int zdialog_add_widget(zdialog *zd,                                        //  add widget to zdialog
       cchar *type, cchar *name, cchar *pname,                              //  (alternative form)
-      cchar *data, cchar *options);                                        //  "scc=nn|homog|expand|space=nn|wrap"
+      cchar *data, cchar *options);                                        //  "size=nn|homog|expand|space=nn|wrap"
 
-int zdialog_valid(zdialog *zd);                                            //  return 1/0 if zdialog valid/invalid
+int zdialog_valid(zdialog *zd, int errmess = 1);                           //  return 1/0 if zdialog valid/invalid
 GtkWidget * zdialog_widget(zdialog *zd, cchar *name);                      //  GTK widget from zdialog widget name
 int zdialog_add_ttip(zdialog *zd, cchar *wname, cchar *ttip);              //  add popup tool tip to a widget
 int zdialog_resize(zdialog *zd, int width, int height);                    //  set size > widget sizes
 int zdialog_put_data(zdialog *zd, cchar *name, cchar *data);               //  put data in widget (entry, spin ...)
 cchar * zdialog_get_data(zdialog *zd, cchar *name);                        //  get widget data
-int zdialog_set_limits(zdialog *zd, cchar *name, double min, double max);  //  set new widget limits (spin, scale)
+int zdialog_set_limits(zdialog *, cchar *name, double min, double max);    //  set new widget limits (spin, scale)
+int zdialog_rescale(zdialog *zd, cchar *wname, float, float, float);       //  rescale widget, lo/neut/hi vals    v.6.0
 
 typedef int zdialog_event(zdialog *zd, cchar *name);                       //  widget event callback function
 int zdialog_run(zdialog *zd, zdialog_event = 0, cchar *posn = 0);          //  run dialog, handle events
@@ -466,6 +476,8 @@ void zdialog_set_cursor(zdialog *zd, GdkCursor *cursor);                   //  s
 int zdialog_stuff(zdialog *zd, cchar *name, cchar *data);                  //  stuff string data into widget
 int zdialog_stuff(zdialog *zd, cchar *name, int  data);                    //  stuff int data
 int zdialog_stuff(zdialog *zd, cchar *name, double data);                  //  stuff double data
+int zdialog_stuff(zdialog *zd, cchar *name, double data, cchar *format);   //  stuff double data, formatted
+int zdialog_labelfont(zdialog *zd, cchar *lab, cchar *font, cchar *txt);   //  stuff label text with font
 
 int zdialog_fetch(zdialog *zd, cchar *name, char *data, int maxcc);        //  get string data from widget
 int zdialog_fetch(zdialog *zd, cchar *name, int  &data);                   //  get int data
@@ -476,7 +488,7 @@ int zdialog_cb_app(zdialog *zd, cchar *name, cchar *data);                 //  a
 int zdialog_cb_prep(zdialog *zd, cchar *name, cchar *data);                //  prepend entry to combo drop down list
 char * zdialog_cb_get(zdialog *zd, cchar *name, int Nth);                  //  get combo drop down list Nth entry
 int zdialog_cb_delete(zdialog *zd, cchar *name, cchar *data);              //  delete combo drop down list entry
-int zdialog_cb_clear(zdialog *zd, cchar *name);                            //  clear all combo box entries 
+int zdialog_cb_clear(zdialog *zd, cchar *name);                            //  clear all combo box entries
 int zdialog_cb_popup(zdialog *zd, cchar *name);                            //  show all combo box list entries
 
 int  zdialog_positions(cchar *action);                                     //  load or save zdialog window positions
@@ -490,16 +502,16 @@ int zdialog_restore_inputs(zdialog *zd);                                   //  r
 //  write text to popup window, shell command to popup window
 
 GtkWidget * write_popup_text(cchar *action, cchar *text = 0, int ww = 0, int hh = 0, GtkWidget *parent = 0);
-int popup_command(cchar *command, int ww = 400, int hh = 300, GtkWidget *parent = 0);
+int popup_command(cchar *command, int ww = 400, int hh = 300, GtkWidget *parent = 0, int top = 0);
 
 //  popup message dialogs
 
-void zmessageACK(GtkWidget *parent, cchar *title, cchar *format, ... );             //  display message, wait for OK
+void zmessageACK(GtkWidget *parent, cchar *format, ... );                           //  display message, wait for OK
 void zmessLogACK(GtkWidget *parent, cchar *format, ... );                           //  same, with log to STDOUT
-int zmessageYN(GtkWidget *parent, cchar *format, ... );                             //  display message, wait for YES/NO
+int  zmessageYN(GtkWidget *parent, cchar *format, ... );                            //  display message, wait for YES/NO
 zdialog * zmessage_post(GtkWidget *parent, int secs, cchar *format, ...);           //  show message, timeout or cancel
-char * zdialog_text(GtkWidget *parent, cchar * title, cchar * initext);             //  get short text input from user
-int zdialog_choose(cchar *title, GtkWidget *parent, cchar *format, ...);            //  show message, return choice 
+char * zdialog_text(GtkWidget *parent, cchar *title, cchar *inittext);              //  get short text input from user
+int  zdialog_choose(GtkWidget *parent, cchar *message, ...);                        //  show message, return choice
 void poptext_mouse(cchar *text, int dx, int dy, float s1, float s2);                //  show popup text at mouse posn
 void poptext_window(cchar *text, GtkWindow *, int mx, int my, float s1, float s2);  //  show popup text at window posn
 int  poptext_killnow();                                                             //  kill current popup window
@@ -507,8 +519,8 @@ int  popup_image(cchar *imagefile, GtkWindow *parent, int Fnewin, int size);
 
 //  file chooser dialogs for one file or multiple files
 
-char  * zgetfile(cchar *title, cchar *action, cchar *file, cchar *butt = 0);
-char ** zgetfiles(cchar *title, cchar *action, cchar *file, cchar *butt = 0);
+char  * zgetfile(cchar *title, GtkWindow *parent, cchar *action, cchar *file, int hidden = 0);
+char ** zgetfiles(cchar *title, GtkWindow *parent, cchar *action, cchar *file, int hidden = 0);
 
 //  print an image file, choosing printer, paper, orientation, margins, and scale
 
@@ -521,26 +533,11 @@ void drag_drop_connect(GtkWidget *window, drag_drop_func);                 //  c
 
 //  miscellaneous GDK/GTK functions
 
-GdkPixbuf * get_thumbnail(char *fpath, int size);                          //  get sized thumbnail for image file
+PIXBUF * get_thumbnail(cchar *fpath, int size);                            //  get sized thumbnail for image file
 GdkCursor * zmakecursor(cchar *iconfile);                                  //  make a cursor from an image file
-GdkPixbuf * gdk_pixbuf_rotate(GdkPixbuf *, float deg, int alfa = 0);       //  rotate pixbuf through any angle
-
-/**************************************************************************/
-
-//  parameter management functions
-
-int initParmlist(int max);                                                 //  initz. parameter list
-int initz_userParms();                                                     //  load or initialize user parms
-int loadParms(cchar * filename);                                           //  load parameters from a file
-int loadParms();                                                           //   + user file select dialog
-int saveParms(cchar * filename);                                           //  save parameters to a file
-int saveParms();                                                           //   + user file select dialog
-int setParm(cchar * parmname, double parmval);                             //  set parameter value
-double getParm(cchar * parmname);                                          //  get parameter value
-char * getParm(int Nth);                                                   //  get Nth parameter name (0-based)
-int listParms(GtkWidget *textWin);                                         //  list all parameters in given window 
-int editParms(GtkWidget *textWin = 0, int addp = 0);                       //  parameter editor
-
+PIXBUF * gdk_pixbuf_rotate(PIXBUF *, float deg, int alfa = 0);             //  rotate pixbuf through any angle
+PIXBUF * gdk_pixbuf_stripalpha(PIXBUF *pixbuf);                            //  strip alpha channel from pixbuf
+PIXBUF * text_pixbuf(cchar *text, cchar *font, int fsize, GtkWidget *);    //  create pixbuf with text using font
 
 /**************************************************************************
    C++ classes
@@ -621,7 +618,7 @@ class  Queue
 {
    char        wmi[8];
    Vxstring  * vd;                                                         //  vector of xstrings
-   mutex_tp    qmutex;                                                     //  for multi-thread access
+   mutex_t     qmutex;                                                     //  for multi-thread access
    int         qcap;                                                       //  queue capacity
    int         qcount;                                                     //  curr. queue count
    int         ent1;                                                       //  first entry pointer
